@@ -1,6 +1,7 @@
 package Net::OAI::Base;
 
 use strict;
+use Carp qw ( croak );
 
 =head1 NAME
 
@@ -84,6 +85,30 @@ sub errorString {
     return( undef );
 }
 
+=head2 HTTPRetryAfter()
+
+Returns the HTTP Retry-After header in case of HTTP level errors.
+
+=cut
+
+sub HTTPRetryAfter {
+    my ( $self ) = @_;
+    return $self->{ error }->HTTPRetryAfter();
+}
+
+
+=head2 HTTPError()
+
+Returns the HTTP::Response object in case of HTTP level errors.
+
+=cut
+
+sub HTTPError {
+    my ( $self ) = @_;
+    return $self->{ error }->HTTPError();
+}
+
+
 =head2 resumptionToken() 
 
 Returns a Net::OAI::ResumptionToken object associated with the call. If 
@@ -106,10 +131,12 @@ as XML.
 
 sub xml {
     my(  $self, %args ) = shift;
-    open( XML, $self->{ file } ) || die "unable to open $self->{ file }";
+    return undef unless $self->{ file };    # not set eg. after HTTP error
+    open( XML, $self->{ file } ) or croak "unable to open file ".$self->{ file };
     ## slurp entire file into $xml
     local $/ = undef;
     my $xml = <XML>;
+    close(XML);            # prevent tempfile leak on Win32
     return( $xml );
 }
 
@@ -128,7 +155,7 @@ sub handleResumptionToken {
     my ( $self, $method ) = @_;
 
     my $harvester = exists( $self->{ harvester } ) ? $self->{ harvester } : 0;
-    return() if ref($harvester) ne 'Net::OAI::Harvester';
+    return() unless $harvester && $harvester->isa('Net::OAI::Harvester');
 
     my $rToken = $self->resumptionToken();
     if ( $rToken ) { 
@@ -160,13 +187,4 @@ sub handleResumptionToken {
 
 =cut
 
-# remove any temp files, when object is destroyed
-
-sub DESTROY {
-    my $self = shift;
-    if ( $self->{ file } ) { 
-	unlink( $self->{ file } );
-    }
-}
-
 1;
